<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="主机名称" prop="hostName">
        <el-input v-model="formData.hostName" placeholder="请输入主机名称" />
      </el-form-item>
      <el-form-item label="服务器ip" prop="hostIp">
        <el-input v-model="formData.hostIp" placeholder="请输入服务器ip" />
      </el-form-item>
      <el-form-item label="服务名" prop="serverName">
        <el-input v-model="formData.serverName" placeholder="请输入服务名" />
      </el-form-item>
      <el-form-item label="总内存" prop="physicalTotal">
        <el-input v-model="formData.physicalTotal" placeholder="请输入总物理内存" />
      </el-form-item>
      <el-form-item label="已用内存" prop="physicalUsed">
        <el-input v-model="formData.physicalUsed" placeholder="请输入已用物理内存" />
      </el-form-item>
      <el-form-item label="空闲内存" prop="physicalFree">
        <el-input v-model="formData.physicalFree" placeholder="请输入空闲内存" />
      </el-form-item>
      <el-form-item label="内存使用率" prop="physicalUsage">
        <el-input v-model="formData.physicalUsage" placeholder="请输入物理内存使用率" />
      </el-form-item>
      <el-form-item label="jvm运行总内存" prop="runtimeTotal">
        <el-input v-model="formData.runtimeTotal" placeholder="请输入jvm运行总内存" />
      </el-form-item>
      <el-form-item label="jvm最大内存" prop="runtimeMax">
        <el-input v-model="formData.runtimeMax" placeholder="请输入jvm最大内存" />
      </el-form-item>
      <el-form-item label="jvm已用内存" prop="runtimeUsed">
        <el-input v-model="formData.runtimeUsed" placeholder="请输入jvm已用内存" />
      </el-form-item>
      <el-form-item label="jvm空闲内存" prop="runtimeFree">
        <el-input v-model="formData.runtimeFree" placeholder="请输入jvm空闲内存" />
      </el-form-item>
      <el-form-item label="jvm内存使用率" prop="runtimeUsage">
        <el-input v-model="formData.runtimeUsage" placeholder="请输入jvm内存使用率" />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { MonitorMemApi, MonitorMemVO } from '@/api/infra/monitormem'

/** 内存监控日志 表单 */
defineOptions({ name: 'MonitorMemForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  hostName: undefined,
  hostIp: undefined,
  serverName: undefined,
  physicalTotal: undefined,
  physicalUsed: undefined,
  physicalFree: undefined,
  physicalUsage: undefined,
  runtimeTotal: undefined,
  runtimeMax: undefined,
  runtimeUsed: undefined,
  runtimeFree: undefined,
  runtimeUsage: undefined,
})
const formRules = reactive({
  hostName: [{ required: true, message: '主机名称不能为空', trigger: 'blur' }],
  hostIp: [{ required: true, message: '服务器ip不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await MonitorMemApi.getMonitorMem(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as MonitorMemVO
    if (formType.value === 'create') {
      await MonitorMemApi.createMonitorMem(data)
      message.success(t('common.createSuccess'))
    } else {
      await MonitorMemApi.updateMonitorMem(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    hostName: undefined,
    hostIp: undefined,
    serverName: undefined,
    physicalTotal: undefined,
    physicalUsed: undefined,
    physicalFree: undefined,
    physicalUsage: undefined,
    runtimeTotal: undefined,
    runtimeMax: undefined,
    runtimeUsed: undefined,
    runtimeFree: undefined,
    runtimeUsage: undefined,
  }
  formRef.value?.resetFields()
}
</script>
